@@ -14,8 +14,7 @@ except ImportError:
     import sys
     sys.path.append(".")
     import spotpy
-from spotpy.examples.spot_setup_hymod_exe import spot_setup
-#from spotpy.examples.spot_setup_hymod_python import spot_setup
+from spotpy.examples.spot_setup_hymod_python import spot_setup
 
 
 if __name__ == "__main__":
